Struct ross_protocol::event::button::ButtonPressedEvent [−][src]
pub struct ButtonPressedEvent {
pub receiver_address: u16,
pub button_address: u16,
pub index: u8,
}Fields
receiver_address: u16index: u8Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more