Struct ross_protocol::event::button::ButtonReleasedEvent
source · [−]pub struct ButtonReleasedEvent {
pub receiver_address: u16,
pub button_address: u16,
pub index: u8,
}Fields
receiver_address: u16index: u8Trait Implementations
sourceimpl ConvertPacket<ButtonReleasedEvent> for ButtonReleasedEvent
impl ConvertPacket<ButtonReleasedEvent> for ButtonReleasedEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Debug for ButtonReleasedEvent
impl Debug for ButtonReleasedEvent
sourceimpl Ord for ButtonReleasedEvent
impl Ord for ButtonReleasedEvent
sourceimpl PartialEq<ButtonReleasedEvent> for ButtonReleasedEvent
impl PartialEq<ButtonReleasedEvent> for ButtonReleasedEvent
sourcefn eq(&self, other: &ButtonReleasedEvent) -> bool
fn eq(&self, other: &ButtonReleasedEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ButtonReleasedEvent) -> bool
fn ne(&self, other: &ButtonReleasedEvent) -> bool
This method tests for !=.
sourceimpl PartialOrd<ButtonReleasedEvent> for ButtonReleasedEvent
impl PartialOrd<ButtonReleasedEvent> for ButtonReleasedEvent
sourcefn partial_cmp(&self, other: &ButtonReleasedEvent) -> Option<Ordering>
fn partial_cmp(&self, other: &ButtonReleasedEvent) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for ButtonReleasedEvent
impl StructuralEq for ButtonReleasedEvent
impl StructuralPartialEq for ButtonReleasedEvent