Struct ross_protocol::event::configurator::ConfiguratorHelloEvent
source · [−]pub struct ConfiguratorHelloEvent {}Trait Implementations
sourceimpl ConvertPacket<ConfiguratorHelloEvent> for ConfiguratorHelloEvent
impl ConvertPacket<ConfiguratorHelloEvent> for ConfiguratorHelloEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Debug for ConfiguratorHelloEvent
impl Debug for ConfiguratorHelloEvent
sourceimpl Ord for ConfiguratorHelloEvent
impl Ord for ConfiguratorHelloEvent
sourceimpl PartialOrd<ConfiguratorHelloEvent> for ConfiguratorHelloEvent
impl PartialOrd<ConfiguratorHelloEvent> for ConfiguratorHelloEvent
sourcefn partial_cmp(&self, other: &ConfiguratorHelloEvent) -> Option<Ordering>
fn partial_cmp(&self, other: &ConfiguratorHelloEvent) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for ConfiguratorHelloEvent
impl StructuralEq for ConfiguratorHelloEvent
impl StructuralPartialEq for ConfiguratorHelloEvent