Enum ross_protocol::event::general::PeripheralValue [−][src]
pub enum PeripheralValue {
Bcm(BcmValue),
Relay(RelayValue),
}Variants
Bcm(BcmValue)
Tuple Fields
0: BcmValueRelay(RelayValue)
Tuple Fields
0: RelayValueTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more