Fields
receiver_address: u16transmitter_address: u16Trait Implementations
sourceimpl ConvertPacket<AckEvent> for AckEvent
impl ConvertPacket<AckEvent> for AckEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Ord for AckEvent
impl Ord for AckEvent
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<AckEvent> for AckEvent
impl PartialEq<AckEvent> for AckEvent
sourceimpl PartialOrd<AckEvent> for AckEvent
impl PartialOrd<AckEvent> for AckEvent
sourcefn partial_cmp(&self, other: &AckEvent) -> Option<Ordering>
fn partial_cmp(&self, other: &AckEvent) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for AckEvent
impl StructuralEq for AckEvent
impl StructuralPartialEq for AckEvent