Struct ross_protocol::event::general::PeripheralDataEvent [−][src]
pub struct PeripheralDataEvent {
pub receiver_address: u16,
pub peripheral_address: u16,
pub peripheral_index: u8,
pub peripheral_value: PeripheralValue,
}Fields
receiver_address: u16peripheral_address: u16peripheral_index: u8peripheral_value: PeripheralValueTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more