Struct ross_protocol::event::internal::SystemTickEvent
source · [−]pub struct SystemTickEvent {
pub receiver_address: u16,
}Fields
receiver_address: u16Trait Implementations
sourceimpl ConvertPacket<SystemTickEvent> for SystemTickEvent
impl ConvertPacket<SystemTickEvent> for SystemTickEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Debug for SystemTickEvent
impl Debug for SystemTickEvent
sourceimpl Ord for SystemTickEvent
impl Ord for SystemTickEvent
sourceimpl PartialEq<SystemTickEvent> for SystemTickEvent
impl PartialEq<SystemTickEvent> for SystemTickEvent
sourcefn eq(&self, other: &SystemTickEvent) -> bool
fn eq(&self, other: &SystemTickEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &SystemTickEvent) -> bool
fn ne(&self, other: &SystemTickEvent) -> bool
This method tests for !=.
sourceimpl PartialOrd<SystemTickEvent> for SystemTickEvent
impl PartialOrd<SystemTickEvent> for SystemTickEvent
sourcefn partial_cmp(&self, other: &SystemTickEvent) -> Option<Ordering>
fn partial_cmp(&self, other: &SystemTickEvent) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for SystemTickEvent
impl StructuralEq for SystemTickEvent
impl StructuralPartialEq for SystemTickEvent