Enum ross_protocol::event::message::MessageValue [−][src]
Variants
U8(u8)
Tuple Fields
0: u8U16(u16)
Tuple Fields
0: u16U32(u32)
Tuple Fields
0: u32Bool(bool)
Tuple Fields
0: boolTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more