Struct ross_protocol::event::message::MessageEvent
source · [−]pub struct MessageEvent {
pub receiver_address: u16,
pub transmitter_address: u16,
pub code: u16,
pub value: MessageValue,
}Fields
receiver_address: u16transmitter_address: u16code: u16value: MessageValueTrait Implementations
sourceimpl ConvertPacket<MessageEvent> for MessageEvent
impl ConvertPacket<MessageEvent> for MessageEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Debug for MessageEvent
impl Debug for MessageEvent
sourceimpl Ord for MessageEvent
impl Ord for MessageEvent
sourcefn cmp(&self, other: &MessageEvent) -> Ordering
fn cmp(&self, other: &MessageEvent) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<MessageEvent> for MessageEvent
impl PartialEq<MessageEvent> for MessageEvent
sourcefn eq(&self, other: &MessageEvent) -> bool
fn eq(&self, other: &MessageEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourceimpl PartialOrd<MessageEvent> for MessageEvent
impl PartialOrd<MessageEvent> for MessageEvent
sourcefn partial_cmp(&self, other: &MessageEvent) -> Option<Ordering>
fn partial_cmp(&self, other: &MessageEvent) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for MessageEvent
impl StructuralEq for MessageEvent
impl StructuralPartialEq for MessageEvent