Struct ross_protocol::event::programmer::ProgrammerHelloEvent
source · [−]pub struct ProgrammerHelloEvent {
pub programmer_address: u16,
}Fields
programmer_address: u16Trait Implementations
sourceimpl ConvertPacket<ProgrammerHelloEvent> for ProgrammerHelloEvent
impl ConvertPacket<ProgrammerHelloEvent> for ProgrammerHelloEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Debug for ProgrammerHelloEvent
impl Debug for ProgrammerHelloEvent
sourceimpl Ord for ProgrammerHelloEvent
impl Ord for ProgrammerHelloEvent
sourcefn cmp(&self, other: &ProgrammerHelloEvent) -> Ordering
fn cmp(&self, other: &ProgrammerHelloEvent) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<ProgrammerHelloEvent> for ProgrammerHelloEvent
impl PartialEq<ProgrammerHelloEvent> for ProgrammerHelloEvent
sourcefn eq(&self, other: &ProgrammerHelloEvent) -> bool
fn eq(&self, other: &ProgrammerHelloEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourceimpl PartialOrd<ProgrammerHelloEvent> for ProgrammerHelloEvent
impl PartialOrd<ProgrammerHelloEvent> for ProgrammerHelloEvent
sourcefn partial_cmp(&self, other: &ProgrammerHelloEvent) -> Option<Ordering>
fn partial_cmp(&self, other: &ProgrammerHelloEvent) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for ProgrammerHelloEvent
impl StructuralEq for ProgrammerHelloEvent
impl StructuralPartialEq for ProgrammerHelloEvent