pub struct ProgrammerSetDeviceAddressEvent {
pub receiver_address: u16,
pub programmer_address: u16,
pub new_address: u16,
}Fields
receiver_address: u16programmer_address: u16new_address: u16Trait Implementations
sourceimpl ConvertPacket<ProgrammerSetDeviceAddressEvent> for ProgrammerSetDeviceAddressEvent
impl ConvertPacket<ProgrammerSetDeviceAddressEvent> for ProgrammerSetDeviceAddressEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Ord for ProgrammerSetDeviceAddressEvent
impl Ord for ProgrammerSetDeviceAddressEvent
sourceimpl PartialEq<ProgrammerSetDeviceAddressEvent> for ProgrammerSetDeviceAddressEvent
impl PartialEq<ProgrammerSetDeviceAddressEvent> for ProgrammerSetDeviceAddressEvent
sourcefn eq(&self, other: &ProgrammerSetDeviceAddressEvent) -> bool
fn eq(&self, other: &ProgrammerSetDeviceAddressEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ProgrammerSetDeviceAddressEvent) -> bool
fn ne(&self, other: &ProgrammerSetDeviceAddressEvent) -> bool
This method tests for !=.
sourceimpl PartialOrd<ProgrammerSetDeviceAddressEvent> for ProgrammerSetDeviceAddressEvent
impl PartialOrd<ProgrammerSetDeviceAddressEvent> for ProgrammerSetDeviceAddressEvent
sourcefn partial_cmp(
&self,
other: &ProgrammerSetDeviceAddressEvent
) -> Option<Ordering>
fn partial_cmp(
&self,
other: &ProgrammerSetDeviceAddressEvent
) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for ProgrammerSetDeviceAddressEvent
impl StructuralEq for ProgrammerSetDeviceAddressEvent
impl StructuralPartialEq for ProgrammerSetDeviceAddressEvent