pub struct ProgrammerStartFirmwareUpgradeEvent {
pub receiver_address: u16,
pub programmer_address: u16,
pub firmware_size: u32,
}Fields
receiver_address: u16programmer_address: u16firmware_size: u32Trait Implementations
sourceimpl ConvertPacket<ProgrammerStartFirmwareUpgradeEvent> for ProgrammerStartFirmwareUpgradeEvent
impl ConvertPacket<ProgrammerStartFirmwareUpgradeEvent> for ProgrammerStartFirmwareUpgradeEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Ord for ProgrammerStartFirmwareUpgradeEvent
impl Ord for ProgrammerStartFirmwareUpgradeEvent
sourcefn cmp(&self, other: &ProgrammerStartFirmwareUpgradeEvent) -> Ordering
fn cmp(&self, other: &ProgrammerStartFirmwareUpgradeEvent) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<ProgrammerStartFirmwareUpgradeEvent> for ProgrammerStartFirmwareUpgradeEvent
impl PartialEq<ProgrammerStartFirmwareUpgradeEvent> for ProgrammerStartFirmwareUpgradeEvent
sourcefn eq(&self, other: &ProgrammerStartFirmwareUpgradeEvent) -> bool
fn eq(&self, other: &ProgrammerStartFirmwareUpgradeEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourceimpl PartialOrd<ProgrammerStartFirmwareUpgradeEvent> for ProgrammerStartFirmwareUpgradeEvent
impl PartialOrd<ProgrammerStartFirmwareUpgradeEvent> for ProgrammerStartFirmwareUpgradeEvent
sourcefn partial_cmp(
&self,
other: &ProgrammerStartFirmwareUpgradeEvent
) -> Option<Ordering>
fn partial_cmp(
&self,
other: &ProgrammerStartFirmwareUpgradeEvent
) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for ProgrammerStartFirmwareUpgradeEvent
impl StructuralEq for ProgrammerStartFirmwareUpgradeEvent
impl StructuralPartialEq for ProgrammerStartFirmwareUpgradeEvent