Struct ross_protocol::event::relay::RelaySetValueEvent
source · [−]pub struct RelaySetValueEvent {
pub relay_address: u16,
pub transmitter_address: u16,
pub index: u8,
pub value: RelayValue,
}Fields
relay_address: u16transmitter_address: u16index: u8value: RelayValueTrait Implementations
sourceimpl ConvertPacket<RelaySetValueEvent> for RelaySetValueEvent
impl ConvertPacket<RelaySetValueEvent> for RelaySetValueEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Debug for RelaySetValueEvent
impl Debug for RelaySetValueEvent
sourceimpl Ord for RelaySetValueEvent
impl Ord for RelaySetValueEvent
sourceimpl PartialEq<RelaySetValueEvent> for RelaySetValueEvent
impl PartialEq<RelaySetValueEvent> for RelaySetValueEvent
sourcefn eq(&self, other: &RelaySetValueEvent) -> bool
fn eq(&self, other: &RelaySetValueEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &RelaySetValueEvent) -> bool
fn ne(&self, other: &RelaySetValueEvent) -> bool
This method tests for !=.
sourceimpl PartialOrd<RelaySetValueEvent> for RelaySetValueEvent
impl PartialOrd<RelaySetValueEvent> for RelaySetValueEvent
sourcefn partial_cmp(&self, other: &RelaySetValueEvent) -> Option<Ordering>
fn partial_cmp(&self, other: &RelaySetValueEvent) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for RelaySetValueEvent
impl StructuralEq for RelaySetValueEvent
impl StructuralPartialEq for RelaySetValueEvent