pub enum FrameError {
FrameIsStandard,
FrameIsRemote,
FrameIdMissing,
WrongSize,
CobsError,
}Variants
FrameIsStandard
Received a standard frame instead of an extended one
FrameIsRemote
Received a remote frame instead of a data one
FrameIdMissing
Part of the frame id is missing
WrongSize
Frame has a different size than expected
CobsError