pub enum FrameId {
LastFrameId(u16),
CurrentFrameId(u16),
}
Frame id for packets with more than one frame
Last frame id inside current packet (12 bits)
Tuple Fields of LastFrameId
Current frame id (12 bits)
Tuple Fields of CurrentFrameId
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.