Enum ross_protocol::ross_frame::RossFrameId [−][src]
Frame id for packets with more than one frame
Variants
Last frame id inside current packet (12 bits)
Tuple Fields of LastFrameId
0: u16Current frame id (12 bits)
Tuple Fields of CurrentFrameId
0: u16Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.