Enum ross_protocol::ross_packet::RossPacketBuilderError [−][src]
pub enum RossPacketBuilderError {
OutOfOrder,
SingleFramePacket,
TooManyFrames,
WrongFrameType,
DeviceAddressMismatch,
MissingFrames,
}Variants
Frame supplied was not the next frame in the sequence+
Expected a multi frame packet but a single frame packet was given
Expected less frames to be in the packet+
Expected an error frame but a data frame was given or the other way around+
The frame given was transmitted by a different device than the previous frames+
Expected more frames+