Struct ross_protocol::event::bootloader::BootloaderHelloEvent
source · [−]Fields
programmer_address: u16bootloader_address: u16Trait Implementations
sourceimpl ConvertPacket<BootloaderHelloEvent> for BootloaderHelloEvent
impl ConvertPacket<BootloaderHelloEvent> for BootloaderHelloEvent
fn try_from_packet(packet: &Packet) -> Result<Self, ConvertPacketError>
fn to_packet(&self) -> Packet
sourceimpl Debug for BootloaderHelloEvent
impl Debug for BootloaderHelloEvent
sourceimpl Ord for BootloaderHelloEvent
impl Ord for BootloaderHelloEvent
sourceimpl PartialEq<BootloaderHelloEvent> for BootloaderHelloEvent
impl PartialEq<BootloaderHelloEvent> for BootloaderHelloEvent
sourcefn eq(&self, other: &BootloaderHelloEvent) -> bool
fn eq(&self, other: &BootloaderHelloEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &BootloaderHelloEvent) -> bool
fn ne(&self, other: &BootloaderHelloEvent) -> bool
This method tests for !=.
sourceimpl PartialOrd<BootloaderHelloEvent> for BootloaderHelloEvent
impl PartialOrd<BootloaderHelloEvent> for BootloaderHelloEvent
sourcefn partial_cmp(&self, other: &BootloaderHelloEvent) -> Option<Ordering>
fn partial_cmp(&self, other: &BootloaderHelloEvent) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for BootloaderHelloEvent
impl StructuralEq for BootloaderHelloEvent
impl StructuralPartialEq for BootloaderHelloEvent