Struct ross_protocol::event::programmer::ProgrammerSetDeviceAddressEvent [−][src]
pub struct ProgrammerSetDeviceAddressEvent {
pub receiver_address: u16,
pub programmer_address: u16,
pub new_address: u16,
}Fields
receiver_address: u16programmer_address: u16new_address: u16Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more