Struct ross_protocol::event::relay::RelaySetValueEvent [−][src]
pub struct RelaySetValueEvent {
pub relay_address: u16,
pub transmitter_address: u16,
pub index: u8,
pub value: RelayValue,
}Fields
relay_address: u16transmitter_address: u16index: u8value: RelayValueTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more